<?php

namespace App\Core;

/**
 * Autoloader PSR-4 pour les classes de l'application.
 */
class Autoloader
{
    /**
     * Enregistre l'autoloader dans la pile de chargement de PHP.
     */
    public static function register()
    {
        spl_autoload_register(function ($class) {
            // Préfixe du namespace de l'application
            $prefix = 'App\\';

            // Répertoire de base où se trouvent les fichiers de l'application (src/)
            $baseDir = __DIR__ . '/../'; // Cela pointe vers /app/src/

            // Vérifie si la classe utilise le préfixe du namespace
            $len = strlen($prefix);
            if (strncmp($prefix, $class, $len) !== 0) {
                // Si la classe n'utilise pas notre préfixe, passe au prochain autoloader enregistré
                return;
            }

            // Récupère le nom de la classe relatif au namespace de base
            $relativeClass = substr($class, $len);

            // Convertit le nom de la classe relatif en chemin de fichier
            // Remplace les séparateurs de namespace par des séparateurs de répertoire et ajoute l'extension .php
            $file = $baseDir . str_replace('\\', '/', $relativeClass) . '.php';

            // Si le fichier existe, l'inclut
            if (file_exists($file)) {
                require $file;
            }
        });
    }
}
